#ifndef _APP_SEARCH_WIDGET_
#define _APP_SEARCH_WIDGET_

#include <glib-object.h>
#include <libhildondesktop/libhildondesktop.h>

G_BEGIN_DECLS

typedef struct _AppSearchHomePlugin AppSearchHomePlugin;
typedef struct _AppSearchHomePluginClass AppSearchHomePluginClass;


#define APP_SEARCH_TYPE_HOME_PLUGIN (app_search_home_plugin_get_type())
#define APP_SEARCH_HOME_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), APP_SEARCH_TYPE_HOME_PLUGIN, AppSearchHomePlugin))
#define APP_SEARCH_HOME_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), APP_SEARCH_TYPE_HOME_PLUGIN, AppSearchHomePluginClass))
#define APP_SEARCH_IS_HOME_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), APP_SEARCH_TYPE_HOME_PLUGIN))
#define APP_SEARCH_IS_HOME_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), APP_SEARCH_TYPE_HOME_PLUGIN))
#define APP_SEARCH_HOME_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), APP_SEARCH_TYPE_HOME_PLUGIN, AppSearchHomePluginClass))

typedef struct _AppSearchHomePluginPrivate AppSearchHomePluginPrivate;
struct _AppSearchHomePlugin
{
  HDHomePluginItem hitem;
  AppSearchHomePluginPrivate* priv;
};

struct _AppSearchHomePluginClass
{
  HDHomePluginItemClass parent_class;
};

GType app_search_home_plugin_get_type(void);

G_END_DECLS

#endif
